"""Django app made to handle notifications (like Django Snitch) using 
websockets and Django Channels.
"""
__version__ = "1.0.1"


default_app_config = "websocket_notifications.apps.WebsocketNotificationsAppConfig"
